&nbsp;

<div align="center">

[![covalent](https://img.shields.io/badge/covalent-0.208.0rc0-purple)](https://github.com/AgnostiqHQ/covalent)
[![agpl](https://img.shields.io/badge/License-AGPL_v3-blue.svg)](https://www.gnu.org/licenses/agpl-3.0.en.html)

</div>

## Covalent Cloud SDK

[Covalent](https://github.com/AgnostiqHQ/covalent) is a python based workflow orchestration tool used to execute HPC and quantum tasks in heterogenous environments.

Installing Covalent Cloud SDK gives users access to the enterprise version of Covalent.
